==> arduino2proj-0.7.4.tgz: package/lib/targets/gnumake.js <==
import{platform as e}from"os"
import n from"path"
import{Transform as t}from"../config.js"
import{Dump as o}from"../dump.js"
import{CalculateChecksAndOrderDefinitions as r}from"../utils.js"
import{GenBoardDefs as i}from"./gmBoard.js"
import{BuildPlatform as a}from"./gmPlatform.js"
import{MakeDeclDef as s,MakeIfeq as l,MakeIfneq as c,MakeUnDecl as _,MakifyName as u}from"./gmUtils.js"
const f=["INCLUDES","BUILD_FLAGS_C","COMPILER_S_EXTRA_FLAGS","COMPILER_C_EXTRA_FLAGS","COMPILER_CPP_EXTRA_FLAGS","COMPILER_C_ELF_EXTRA_FLAGS","COMPILER_LD_EXTRA_FLAGS","COMPILER_AR_EXTRA_FLAGS","COMPILER_ELF_EXTRA_FLAGS","COMPILER_ELF2HEX_EXTRA_FLAGS","COMPILER_AR_EXTRA_FLAGS","UPLOAD_VERBOSE"]
function $(e){return"  ".repeat(e)}function d(e,n){for(let t=n;t<e.length;t++){const n=e[t],r=$(t)
"neq"===n.op||"eq"===n.op?o()(`${r}if${n.op} (${n.variable}, ${n.value||""})`):"raw"!==n.op?o()(`${r}if${n.op} ${n.variable}`):o()(`${r}if ${n.variable}`)}}function m(e,n){for(;n--;)o()(`${$(--e)}endif`)}function E(e,n,t){if(t===e.length&&t===n.length)return
if(t===e.length)return void d(n,t)
if(t===n.length)return void m(e.length,e.length-t)
const r=e[t],i=n[t]
r.variable!==i.variable?(m(e.length,e.length-t),d(n,t)):r.value&&i.value&&r.value===i.value||void 0===r.value&&void 0===i.value?r.op===i.op?E(e,n,t+1):"neq"===r.op&&"eq"===i.op||"eq"===r.op&&"neq"===i.op||"def"===r.op&&"ndef"===i.op||"ndef"===r.op&&"def"===i.op?(m(e.length,e.length-t-1),o()(`${$(t)}else`),d(n,t+1)):(m(e.length,e.length-t),d(n,t)):"eq"===r.op&&"eq"===i.op?(m(e.length,e.length-t-1),o()(`${$(t)}else ifeq (${i.variable}, ${i.value||""})`),d(n,t+1)):(m(e.length,e.length-t),d(n,t))}const R=new Map([["decl","="],["seq",":="],["add","+="],["?decl","?="]])
function S(e){o()("# And here are all the definitions")
let n=[]
e.forEach((e=>{const r=e.condition.length>0?e.condition:[]
E(n,r,0)
const i=$(e.condition.length),a=R.get(e.type)
if(a){const{name:n,value:r}=t(e.name,e.value)
o()(`${i}${n}${a}${r}`)}n=r})),m(n.length-1,n.length)}function h(e,n,t){const o=`\${COMPILER_${e}_EXTRA_FLAGS} `
if(t.indexOf(o)<0){const e=t.indexOf(n)
e>0&&(t=t.substring(0,e)+o+t.substring(e))}return t}function A(){return"{runtime.platform.path}"}function L(){return"{runtime.hardware.path}"}function p(){return"{runtime.ide.path}"}function P(){switch(e().toLocaleLowerCase()){case"win32":return"windows"
case"darwin":return"macosx"
case"linux":return"linux"
default:throw new Error("Unsupported platform: "+e())}}function g(){return"{build.source.path}"}function I(){return"0"}function U(){return"-O2"}function T(e,n){return()=>{let t=Math.floor(Date.now()/1e3)
return(e||n)&&(t+=3600),`${t}`}}async function O(e,t,u,$){const d=i(u),m=function(e){const t=l("$(OS)","Windows_NT"),o=c("$(OS)","Windows_NT"),r=l("$(uname)","Darwin")
return[s("RUNTIME_OS","windows",[],[t]),s("uname","$(shell uname -s)",[],[o]),s("RUNTIME_OS","macosx",["uname"],[o,r]),_("RUNTIME_OS","linux"),s("RUNTIME_PLATFORM_PATH",n.dirname(e).replaceAll("\\","/")),s("RUNTIME_IDE_VERSION","10819"),s("IDE_VERSION","10819")]}(e),{defs:E,rules:R}=await a(m,d,t,n.dirname(e),$)
!function(e,n,t,i){const{checks:a,defs:s}=r([...e,...n,...t],i,f)
!function(e){o()("# First, add some errors for undefined values"),e.forEach((e=>{o()(`ifndef ${e}`),o()(`  $(error ${e} is not defined!)`),o()("endif")})),o()("\n# Check for some source files\nifeq (${USER_C_SRCS}${USER_CPP_SRCS}${USER_S_SRCS},)\n  $(error You must define USER_C_SRCS, USER_CPP_SRCS, or USER_S_SRCS)\nendif\n")}(a),S(s),function(e){const n=e.filter((e=>"flash"===e.dst)).pop(),t=n?n.src:"unk"
o()(`\n# And now the build rules!\n\n# First, the phony rules that don't produce things\n.PHONY: \${PROJ_NAME} flash clean allclean\n\n# Now the default target\nall: \${BUILD_PATH} \${PROJ_NAME}\n\n# Some house keeping\nclean:\n\t-rm \${USER_OBJS} \${USER_EXTRA}\n\nallclean: clean\n\t-rm -rf \${BUILD_PATH}\n\n# Make us rebuild user code if the makefile(s) change:\n# Needs to be above the deps thing, I think\n\${USER_OBJS} : $(MAKEFILE_LIST)\n\n# Let's start using the generated .d files...\n-include $(ALL_OBJS:.o=.d)\n\n# Next, the project name shortcut, because it's easier\n\${PROJ_NAME}: \${BUILD_PATH} \${BUILD_PATH}/\${PROJ_NAME}.${t}\n\n# Add a 'flash' target\nflash: \${BUILD_PATH}/\${PROJ_NAME}.flash\n\n# And finally, create the directory\n\${BUILD_PATH}:\nifeq ($(RUNTIME_OS),windows)\n\t-@mkdir "$@"\nelse\n\t@test -d "$@" || mkdir -p "$@"\nendif\n\n# Now, on to the actual rules`),e.forEach((e=>{if(o()(""),"o"===e.dst){o()(`\${BUILD_PATH}/%.${e.src}.o : %.${e.src}`)
const n=h(e.src.toUpperCase(),'"$<"',e.command)
o()(`\t${n}\n`),o()(`\${BUILD_PATH}/%.${e.src}.jsn : %.${e.src}`),o()("\t$(file >$@,dir#$(<D))"),o()("\t$(file >>$@,fil#$(<F))"),o()(`\t$(file >>$@,cmd#${n})`)}else if("a"===e.dst){o()("${BUILD_PATH}/system.a : ${SYS_OBJS}")
const n=h("AR",'rcs "$@"',e.command)
o()(`\t${n}\n`)}else if("elf"===e.dst){o()("${BUILD_PATH}/${BUILD_PROJECT_NAME}.elf : ${BUILD_PATH}/system.a ${USER_OBJS}")
const n=h("ELF",'-o "$@"',e.command)
o()(`\t${n}\n`)}else o()("${BUILD_PATH}/${BUILD_PROJECT_NAME}."+e.dst+" : ${BUILD_PATH}/${BUILD_PROJECT_NAME}."+e.src),o()(`\t${e.command}`)})),o()("\n\n${BUILD_PATH}/compile_commands.jsn: ${USER_JSN} ${SYS_JSN}\n\t@cat ${USER_JSN} ${SYS_JSN} > $@\n\ncompile_commands: ${BUILD_PATH} ${BUILD_PATH}/compile_commands.jsn")}(i)}(m,d,E,R)}function D(e){const n=u(e)
return{name:n,expansion:"${"+n+"}"}}export function GetGnuMakeTarget(){return{emit:O,expandName:D,globals:{getRuntimePlatformPath:A,getRuntimeHardwarePath:L,getRuntimeIdePath:p,getRuntimeOs:P,getSourcePath:g,getVendorName:()=>"VENDOR",getBoardId:()=>"BOARD_ID",getFQBN:()=>"fqbn",getLibDiscoveryPhase:I,getOptFlags:U,getTimeUtc:T}}}

==> arduino2proj-0.8.4.tgz: package/lib/targets/gnumake.js <==
import{platform as e}from"os"
import n from"path"
import{Transform as t}from"../config.js"
import{Dump as o}from"../dump.js"
import{CalculateChecksAndOrderDefinitions as r}from"../utils.js"
import{GenBoardDefs as i}from"./gmBoard.js"
import{BuildPlatform as a}from"./gmPlatform.js"
import{MakeDeclDef as s,MakeIfeq as l,MakeIfneq as c,MakeUnDecl as _,MakifyName as f}from"./gmUtils.js"
const u=["INCLUDES","BUILD_FLAGS_C","COMPILER_S_EXTRA_FLAGS","COMPILER_C_EXTRA_FLAGS","COMPILER_CPP_EXTRA_FLAGS","COMPILER_C_ELF_EXTRA_FLAGS","COMPILER_LD_EXTRA_FLAGS","COMPILER_AR_EXTRA_FLAGS","COMPILER_ELF_EXTRA_FLAGS","COMPILER_ELF2HEX_EXTRA_FLAGS","COMPILER_AR_EXTRA_FLAGS","UPLOAD_VERBOSE"]
function $(e){return"  ".repeat(e)}function d(e,n){for(let t=n;t<e.length;t++){const n=e[t],r=$(t)
"neq"===n.op||"eq"===n.op?o()(`${r}if${n.op} (${n.variable}, ${n.value||""})`):"raw"!==n.op?o()(`${r}if${n.op} ${n.variable}`):o()(`${r}if ${n.variable}`)}}function m(e,n){for(;n--;)o()(`${$(--e)}endif`)}function E(e,n,t){if(t===e.length&&t===n.length)return
if(t===e.length)return void d(n,t)
if(t===n.length)return void m(e.length,e.length-t)
const r=e[t],i=n[t]
r.variable!==i.variable?(m(e.length,e.length-t),d(n,t)):r.value&&i.value&&r.value===i.value||void 0===r.value&&void 0===i.value?r.op===i.op?E(e,n,t+1):"neq"===r.op&&"eq"===i.op||"eq"===r.op&&"neq"===i.op||"def"===r.op&&"ndef"===i.op||"ndef"===r.op&&"def"===i.op?(m(e.length,e.length-t-1),o()(`${$(t)}else`),d(n,t+1)):(m(e.length,e.length-t),d(n,t)):"eq"===r.op&&"eq"===i.op?(m(e.length,e.length-t-1),o()(`${$(t)}else ifeq (${i.variable}, ${i.value||""})`),d(n,t+1)):(m(e.length,e.length-t),d(n,t))}const R=new Map([["decl","="],["seq",":="],["add","+="],["?decl","?="]])
function S(e){o()("# And here are all the definitions")
let n=[]
e.forEach((e=>{const r=e.condition.length>0?e.condition:[]
E(n,r,0)
const i=$(e.condition.length),a=R.get(e.type)
if(a){const{name:n,value:r}=t(e.name,e.value)
o()(`${i}${n}${a}${r}`)}n=r})),m(n.length-1,n.length)}function h(e,n,t){const o=`\${COMPILER_${e}_EXTRA_FLAGS} `
if(t.indexOf(o)<0){const e=t.indexOf(n)
e>0&&(t=t.substring(0,e)+o+t.substring(e))}return t}function A(){return"{runtime.platform.path}"}function p(){return"{runtime.hardware.path}"}function L(){return"{runtime.ide.path}"}function P(){switch(e().toLocaleLowerCase()){case"win32":return"windows"
case"darwin":return"macosx"
case"linux":return"linux"
default:throw new Error("Unsupported platform: "+e())}}function g(){return"{build.source.path}"}function I(){return"0"}function U(){return"-O2"}function T(e,n){return()=>{let t=Math.floor(Date.now()/1e3)
return(e||n)&&(t+=3600),`${t}`}}async function O(e,t,f,$){const d=i(f),m=function(e){const t=l("$(OS)","Windows_NT"),o=c("$(OS)","Windows_NT"),r=l("$(uname)","Darwin")
return[s("RUNTIME_OS","windows",[],[t]),s("uname","$(shell uname -s)",[],[o]),s("RUNTIME_OS","macosx",["uname"],[o,r]),_("RUNTIME_OS","linux"),s("RUNTIME_PLATFORM_PATH",n.dirname(e).replaceAll("\\","/")),s("RUNTIME_IDE_VERSION","10819"),s("IDE_VERSION","10819")]}(e),{defs:E,rules:R}=await a(m,d,t,n.dirname(e),$)
!function(e,n,t,i){const{checks:a,defs:s}=r([...e,...n,...t],i,u)
!function(e){o()("# First, add some errors for undefined values"),e.forEach((e=>{o()(`ifndef ${e}`),o()(`  $(error ${e} is not defined!)`),o()("endif")})),o()("\n# Check for some source files\nifeq (${USER_C_SRCS}${USER_CPP_SRCS}${USER_S_SRCS},)\n  $(error You must define USER_C_SRCS, USER_CPP_SRCS, or USER_S_SRCS)\nendif\n")}(a),S(s),function(e){const n=e.filter((e=>"flash"===e.dst)).pop(),t=n?n.src:"unk"
o()(`\n# And now the build rules!\n\n# First, the phony rules that don't produce things\n.PHONY: \${PROJ_NAME} flash clean allclean\n\n# Now the default target\nall: \${BUILD_PATH} \${PROJ_NAME}\n\n# Some house keeping\nclean:\n\t-rm \${USER_OBJS} \${USER_EXTRA}\n\nallclean: clean\n\t-rm -rf \${BUILD_PATH}\n\n# Make us rebuild user code if the makefile(s) change:\n# Needs to be above the deps thing, I think\n\${USER_OBJS} : $(MAKEFILE_LIST)\n\n# Let's start using the generated .d files...\n-include $(ALL_OBJS:.o=.d)\n\n# Next, the project name shortcut, because it's easier\n\${PROJ_NAME}: \${BUILD_PATH} \${BUILD_PATH}/\${PROJ_NAME}.${t}\n\n# Add a 'flash' target\nflash: \${BUILD_PATH}/\${PROJ_NAME}.flash\n\n# And finally, create the directory\n\${BUILD_PATH}:\nifeq ($(RUNTIME_OS),windows)\n\t-@mkdir "$@"\nelse\n\t@test -d "$@" || mkdir -p "$@"\nendif\n\n# Now, on to the actual rules`),e.forEach((e=>{if(o()(""),"o"===e.dst){o()(`\${BUILD_PATH}/%.${e.src}.o : %.${e.src}`)
const n=h(e.src.toUpperCase(),'"$<"',e.command)
o()(`\t${n}\n`),o()(`\${BUILD_PATH}/%.${e.src}.jsn : %.${e.src}`),o()("\t$(file >$@,dir#$(<D))"),o()("\t$(file >>$@,fil#$(<F))"),o()(`\t$(file >>$@,cmd#${n})`)}else if("a"===e.dst){o()("${BUILD_PATH}/system.a : ${SYS_OBJS}")
const n=h("AR",'rcs "$@"',e.command)
o()(`\t${n}\n`)}else if("elf"===e.dst){o()("${BUILD_PATH}/${BUILD_PROJECT_NAME}.elf : ${BUILD_PATH}/system.a ${USER_OBJS}")
const n=h("ELF",'-o "$@"',e.command)
o()(`\t${n}\n`)}else o()("${BUILD_PATH}/${BUILD_PROJECT_NAME}."+e.dst+" : ${BUILD_PATH}/${BUILD_PROJECT_NAME}."+e.src),o()(`\t${e.command}`)})),o()("\n\n${BUILD_PATH}/compile_commands.jsn: ${USER_JSN} ${SYS_JSN}\n\t@cat ${USER_JSN} ${SYS_JSN} > $@\n\ncompile_commands: ${BUILD_PATH} ${BUILD_PATH}/compile_commands.jsn")}(i)}(m,d,E,R)}function D(e){const n=f(e)
return{name:n,expansion:"${"+n+"}"}}export function GetGnuMakeTarget(){return{emit:O,expandName:D,globals:{getRuntimePlatformPath:A,getRuntimeHardwarePath:p,getRuntimeIdePath:L,getRuntimeOs:P,getSourcePath:g,getVendorName:()=>"VENDOR",getBoardId:()=>"BOARD_ID",getFQBN:()=>"fqbn",getLibDiscoveryPhase:I,getOptFlags:U,getTimeUtc:T}}}
